# Varenv Release Note
* version **1.0.7**
* date **26/02/2021**

## BigFix
* on get_env return the correct variable when it's not available on the local env file

## Features Removal
* variables can no longer have alias.
